==> fzf-0.20.0-1-armv6h.pkg.tar.xz: usr/share/doc/fzf/wiki/Related-projects.md <==
### Shell

- https://github.com/atweiden/fzf-extras
- https://github.com/D630/fzf-contrib [discontinued]
- https://github.com/D630/fzf-fs [discontinued]
- https://github.com/uvaes/fzf-marks
- https://github.com/DanielFGray/fzf-scripts
- https://github.com/wfxr/formarks
- https://github.com/rockandska/fzf-obc
- https://github.com/atsepkov/Graphene [ranger-inspired web browser]
- https://github.com/seifferth/cite [extract citekeys from bibtex files]

### Git

- https://github.com/wfxr/forgit
- https://github.com/EfforiaKnight/fizzygit
- https://github.com/laggardkernel/git-ignore

### Vim

- https://github.com/junegunn/fzf.vim
- https://github.com/lvht/fzf-mru [based on viminfo/shada]
- https://github.com/tweekmonster/fzf-filemru
- https://github.com/pbogut/fzf-mru.vim [99% of MRU engine has been taken from CtrlP]
- https://github.com/chew-z/itunes.vim [searching and playing iTunes Library]
- https://github.com/alok/notational-fzf-vim 
- https://github.com/fszymanski/fzf-quickfix
- https://github.com/dominickng/fzf-session.vim

### Emacs

- https://github.com/bling/fzf.el

### Kakoune

- https://github.com/andreyorst/fzf.kak

### Vis

- https://github.com/guillaumecherel/vis-fzf-open

### Tmux

- https://github.com/wfxr/tmux-fzf-url

### Python

- https://github.com/dahlia/iterfzf
- https://github.com/lebedov/fuzzdoc

### Similar implementations

- https://github.com/mooz/percol
- https://github.com/lestrrat/peco
- https://github.com/garybernhardt/selecta
- https://github.com/thoughtbot/pick
- https://github.com/sgtpep/pmenu
- https://github.com/lotabout/skim
- https://github.com/ruyadorno/ipt

### Tools to use with fzf

- https://github.com/edi9999/path-extractor
- https://github.com/genotrance/ff

### Articles

- https://medium.com/@calbertts/docker-and-fuzzy-finder-fzf-4c6416f5e0b5#.8y70iv8nx
- http://weyl.io/blog/2018/02/24/fast-project-finding-with-fzf/ (vim)

==> fzf-0.20.0-3-armv6h.pkg.tar.xz: usr/share/doc/fzf/wiki/Related-projects.md <==
### Shell

- https://github.com/atweiden/fzf-extras
- https://github.com/D630/fzf-contrib [discontinued]
- https://github.com/D630/fzf-fs [discontinued]
- https://github.com/uvaes/fzf-marks
- https://github.com/DanielFGray/fzf-scripts
- https://github.com/3hhh/fzfuncs
- https://github.com/wfxr/formarks
- https://github.com/rockandska/fzf-obc
- https://github.com/lincheney/fzf-tab-completion
- https://github.com/Aloxaf/fzf-tab
- https://github.com/atsepkov/Graphene [ranger-inspired web browser]
- https://github.com/seifferth/cite [extract citekeys from bibtex files]

### Git

- https://github.com/wfxr/forgit
- https://github.com/EfforiaKnight/fizzygit
- https://github.com/laggardkernel/git-ignore
- https://gitlab.com/Energy1011/omgit

### Vim

- https://github.com/junegunn/fzf.vim
- https://github.com/lvht/fzf-mru [based on viminfo/shada]
- https://github.com/tweekmonster/fzf-filemru
- https://github.com/pbogut/fzf-mru.vim [99% of MRU engine has been taken from CtrlP]
- https://github.com/chew-z/itunes.vim [searching and playing iTunes Library]
- https://github.com/alok/notational-fzf-vim 
- https://github.com/fszymanski/fzf-quickfix
- https://github.com/dominickng/fzf-session.vim

### Emacs

- https://github.com/bling/fzf.el

### Kakoune

- https://github.com/andreyorst/fzf.kak

### Vis

- https://github.com/guillaumecherel/vis-fzf-open

### Tmux

- https://github.com/wfxr/tmux-fzf-url

### Python

- https://github.com/dahlia/iterfzf
- https://github.com/lebedov/fuzzdoc

### Other
- [ZFS Boot Menu - Boot environment support for Linux](https://github.com/zdykstra/zfsbootmenu)

### Similar implementations

- https://github.com/mooz/percol
- https://github.com/lestrrat/peco
- https://github.com/garybernhardt/selecta
- https://github.com/thoughtbot/pick
- https://github.com/sgtpep/pmenu
- https://github.com/lotabout/skim
- https://github.com/ruyadorno/ipt

### Tools to use with fzf

- https://github.com/edi9999/path-extractor
- https://github.com/genotrance/ff

### Articles

- https://medium.com/@calbertts/docker-and-fuzzy-finder-fzf-4c6416f5e0b5#.8y70iv8nx
- http://weyl.io/blog/2018/02/24/fast-project-finding-with-fzf/ (vim)
